@@ -26,8 +26,6 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 163 $
- *   $Date: 2013-03-08 14:56:33 +0100 (Fri, 08 Mar 2013) $
  *   
  *   
 */
@@ -40,8 +38,7 @@
 #include "misc.h"
 #include "list.h"
 
-#include "probaTableWrapper.h"
-#include "ioContext.h"
+#include "proba_info.h"
 
 #ifdef WIN32
 #define fstat _fstati64
@@ -54,7 +51,7 @@ extern "C" {
 #endif
 
 typedef enum {
-  unknown,
+  unknown = 0,
   lmalphanum10k,
   lmalphanum5k,
   lmextended,
@@ -69,9 +66,20 @@ typedef enum {
   lmflash,
   nteightxl,
   ntspecialxl,
-  probaTable
+  ntprobafree,
+  ntproba10g,
+  ntproba60g
 } table_kind_t;
 
+typedef enum {
+  preload_none = 0x00,
+  preload_init = 0x01,
+  preload_idx  = 0x02,
+  preload_end  = 0x04,
+  preload_srt  = 0x08,
+  preload_full = preload_init + preload_idx + preload_end + preload_srt
+} table_preload_t;
+
 typedef struct table_t_ {
   table_kind_t kind;
   uint32_t code;
@@ -88,27 +96,32 @@ typedef struct table_t_ {
   int enabled;
   int active;
 
-  FILE *srtfile;
   FILE *idxfile;
   FILE *endfile;
+  FILE *srtfile;
 
-  uint64_t srtsize;
+  uint8_t shared_init;
+
+  uint64_t inisize;
   uint64_t idxsize;
   uint64_t endsize;
-  uint64_t *sizes;
+  uint64_t srtsize;
 
-  probaTableWrapper* ptw;
+  const uint64_t *sizes;
 
-  int preload;
-
-  char *srtmem;
+  void *param;
   char *idxmem;
   char *endmem;
+  char *srtmem;
+
+  void *(*init)(void*);
+  void  (*cleanup)(void*);
 
   void (*find)(void*, void*, void*);
   int (*lookup_idx)(void*, void*, void*);
   int (*lookup_end)(void*, void*, void*);
   int (*lookup_srt)(void*, void*, void*);
+
   int (*check)(void*, void*, void*);
   int (*isvalid)(void*, void*);
 } table_t;
@@ -116,16 +129,18 @@ typedef struct table_t_ {
 table_t *table_alloc(uint32_t code, char *path, int idx);
 void table_free(table_t *tbl);
 
-int table_load(table_t *tbl, contextStruct* cs);
+int table_load(table_t *tbl);
 void table_set_size(table_t *tbl);
 int table_verify(table_t *tbl);
-uint64_t table_preload(table_t *tbl);
-uint64_t table_unload(table_t *tbl);
+uint64_t table_preload(table_t *tbl, table_preload_t preload);
+uint64_t table_unload(table_t *tbl, table_preload_t preload);
 
 uint64_t table_size(table_t *tbl);
-uint64_t table_preload_size(table_t *tbl);
+uint64_t table_preload_size(table_t *tbl, table_preload_t preload);
 int table_open(list_t *tables, const char *dir, const char *tblstr);
 
+table_preload_t table_preload_state(table_t *tbl);
+
 table_kind_t table_kind(uint32_t code);
 const char *table_string(table_kind_t kind);
 
